pub struct FeesEstimateError {
pub _type: String,
pub code: String,
pub message: String,
pub detail: Vec<Value>,
}Expand description
FeesEstimateError : An unexpected error occurred during this operation.
Fields
_type: StringAn error type, identifying either the receiver or the sender as the originator of the error.
code: StringAn error code that identifies the type of error that occurred.
message: StringA message that describes the error condition.
detail: Vec<Value>Additional information that can help the caller understand or fix the issue.
Implementations